pub struct ErrorDetail {
pub field: Option<String>,
pub message: String,
}Expand description
Optional structured validation detail for one request problem.
Fields
field: Option<String>message: StringTrait Implementations
Sourceimpl Clone for ErrorDetail
impl Clone for ErrorDetail
Sourcefn clone(&self) -> ErrorDetail
fn clone(&self) -> ErrorDetail
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ErrorDetail
impl Debug for ErrorDetail
Sourceimpl<'de> Deserialize<'de> for ErrorDetail
impl<'de> Deserialize<'de> for ErrorDetail
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ErrorDetail
Sourceimpl JsonSchema for ErrorDetail
impl JsonSchema for ErrorDetail
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ErrorDetail
impl PartialEq for ErrorDetail
Sourcefn eq(&self, other: &ErrorDetail) -> bool
fn eq(&self, other: &ErrorDetail) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ErrorDetail
impl Serialize for ErrorDetail
impl StructuralPartialEq for ErrorDetail